import OHeader from '@/components/o-header'
import { defineComponent, onMounted, reactive, ref } from 'vue'
import { Button, Cell, CellGroup, Image, showConfirmDialog, Tag } from 'vant'
import styles from './index.module.less'
import iconRefunding from './images/icon_refunding.png'
import icon_success from './images/icon_success.png'
import iconClose from './images/icon_close.png'
import iconTradeing from './images/icon_tradeing.png'
import request from '@/helpers/request'
import { useRoute } from 'vue-router'
import { orderStatus } from '@/constant'
import { browser, moneyFormat } from '@/helpers/utils'
import { useEventListener, useWindowScroll } from '@vueuse/core'
import { useRect } from '@vant/use'

export default defineComponent({
  name: 'payment-result',
  setup() {
    const route = useRoute()
    const state = reactive({
      orders: {} as any,
      goodsInfos: [] as any,
      background: 'transparent',
      color: '#fff',
      backIconColor: 'white' as any
    })
    const getDetails = async () => {
      try {
        if (!route.query.orderNo) return
        const { data } = await request.post(
          '/api-student/open/userOrder/paymentStatus/' + route.query.orderNo
        )

        state.orders = data || {}
        // state.orders.status = 'REFUNDED'
        const tempGoods = data.goodsInfos || []
        tempGoods.forEach((item: any) => {
          const img = item.goodsUrl ? item.goodsUrl.split(',')[0] : ''
          item.goodsUrl = img
        })
        state.goodsInfos = tempGoods
      } catch {
        //
      }
    }

    const onRefund = async () => {
      showConfirmDialog({
        message: '您是否确定撤销退费?'
      }).then(async () => {
        try {
          await request.post('/api-student/userPaymentOrder/cancelRefund/' + route.query.orderNo)
          getDetails()
        } catch {
          //
        }
      })
    }

    const formatImg = (type: any) => {
      const template = {
        WAIT_PAY: iconTradeing,
        PAYING: iconTradeing,
        PAID: icon_success,
        TIMEOUT: iconClose,
        FAIL: iconClose,
        CLOSED: iconClose,
        REFUNDING: iconRefunding,
        REFUNDED: icon_success
      }
      return template[type] || icon_success
    }

    const formatOrderStatus = (status: string) => {
      const temp = {
        WAIT_PAY: '支付中',
        PAYING: '支付中',
        PAID: '支付成功',
        TIMEOUT: '订单超时',
        FAIL: '支付失败',
        CLOSED: '订单关闭',
        REFUNDING: '退款中',
        REFUNDED: '已退款'
      }
      return temp[status]
    }

    onMounted(() => {
      getDetails()
      useEventListener(document, 'scroll', () => {
        const { y } = useWindowScroll()
        if (y.value > 52) {
          state.background = '#fff'
          state.color = '#323333'
          state.backIconColor = 'black'
        } else {
          state.background = 'transparent'
          state.color = '#fff'
          state.backIconColor = 'white'
        }
      })
    })
    return () => (
      <div class={styles.paymentResult}>
        <div class={styles.paymentTitle}>
          {browser().isApp && (
            <OHeader
              border={false}
              background={state.background}
              color={state.color}
              backIconColor={state.backIconColor}
            />
          )}

          {state.orders.id && (
            <>
              <div class={styles.orderType}>
                <Image class={styles.img} src={formatImg(state.orders.status)} />
                <div class={styles.orderInfo}>
                  <span>{formatOrderStatus(state.orders.status)}</span>
                  {state.orders.status === 'PAID' || state.orders.status === 'REFUNDING' ? (
                    <div class={styles.orderPrice}>
                      实付金额：￥{moneyFormat(state.orders.paymentCashAmount)}
                    </div>
                  ) : (
                    ''
                  )}

                  {state.orders.status === 'REFUNDED' && (
                    <div class={styles.orderPrice}>
                      退款金额：￥{moneyFormat(state.orders.paymentCashAmount)}
                    </div>
                  )}
                </div>
              </div>
            </>
          )}
        </div>

        <CellGroup inset class={[styles.cellGroup, styles.mTop]}>
          <Cell>
            {{ title: () => '付款时间', value: () => <span>{state.orders.payTime || '--'}</span> }}
          </Cell>
          <Cell>
            {{ title: () => '订单编号', value: () => <span>{state.orders.orderNo}</span> }}
          </Cell>
        </CellGroup>

        <CellGroup inset class={styles.cellGroup}>
          <div class={styles.buyDetail}>
            <i></i> 购买详情
          </div>
          {state.goodsInfos.map((goods: any) => (
            <Cell>
              {{
                icon: () => <Image class={styles.buyImg} src={goods.goodsUrl} />,
                title: () => (
                  <div class={styles.buyContent}>
                    <p class={styles.goodsTitle}>{goods.goodsName}</p>
                    <Tag
                      color="linear-gradient(135deg, #FF8C4A 0%, #FF531C 100%)"
                      textColor="#fff"
                      class={styles.brandName}
                    >
                      {goods.brandName}
                    </Tag>
                  </div>
                ),
                value: () => <span>x 1</span>
              }}
            </Cell>
          ))}
        </CellGroup>

        {state.orders.status === 'REFUNDING' && browser().isApp && (
          <div class={'btnGroup'}>
            <Button type="primary" round block onClick={onRefund}>
              撤销退费
            </Button>
          </div>
        )}
      </div>
    )
  }
})
