import { defineComponent, PropType } from 'vue'
import { Image, Button } from 'vant'
import iconError from '../../images/icon-error.png'
import styles from './index.module.less'

export default defineComponent({
  name: 'result-mode',
  props: {
    confirmButtonText: {
      type: String,
      default: '去练习'
    },
    cancelButtonText: {
      type: String,
      default: '我知道了'
    },
    status: {
      type: String as PropType<'SUCCESS' | 'FAIL'>,
      default: 'SUCCESS'
    },
    result: {
      type: Object,
      default: () => ({
        tips: '恭喜你，测验通过！',
        score: 0,
        examName: ''
      })
    }
  },
  emits: ['close', 'conform'],
  setup(props, { emit }) {
    return () => (
      <div class={[styles.finishResult, props.status === 'FAIL' && styles.finishFail]}>
        <div class={styles.finishContainer}>
          <div class={styles.finishContent}>
            <div class={styles.scoreNums}>
              {props.result.score}
              <span>分</span>
            </div>
            <div class={styles.scoreName}>{props.result.examName}</div>
            <div class={styles.scoreResult}>{props.result.tips}</div>
          </div>
        </div>

        <div class={styles.finishBtnGroup}>
          <div class={styles.finishLeft} onClick={() => emit('conform')}>
            {props.confirmButtonText}
          </div>
          <div class={styles.finishRight} onClick={() => emit('close')}>
            {props.cancelButtonText}
          </div>
        </div>
      </div>
    )
  }
})
